@@ -16,32 +16,27 @@
 
 static char cmd_output[MSGSIZE + 1];
 static char *cmd_output_ptr = 0;
-static int show_class = 0;
 int bar_hidden = 0;
 
 #define MENU_BASE -10
-#define MENU_ENTRIES 8
+#define MENU_ENTRIES 6
 
 static char *menu[] = {
-	"Menu [1/8]  Pass clicks on to clients?",
-	"Menu [2/8]  Resize windows when tiling?",
-	"Menu [3/8]  Retile when focus changes?",
-	"Menu [4/8]  Show class info on status bar?",
-	"Menu [5/8]  Current window should be floating?",
-	"Menu [6/8]  Current window should be a tool window?",
-	"Menu [7/8]  Current window should be sticky?",
-	"Menu [8/8]  Current window should be tiled?",
+	"Menu [1/6]  Pass clicks on to clients?",
+	"Menu [2/6]  Resize windows when tiling?",
+	"Menu [3/6]  Retile when focus changes?",
+	"Menu [4/6]  Current window should be floating?",
+	"Menu [5/6]  Current window should be a tool window?",
+	"Menu [6/6]  Current window should be sticky?",
 };
 
 static int mlen[] = {
 	38,
 	39,
 	38,
-	42,
 	46,
 	51,
 	44,
-	43,
 };
 
 void do_menu (ScreenInfo *s)
@@ -63,24 +58,17 @@ void do_menu (ScreenInfo *s)
 		toggle_skip_focus (s);
 		break;
 	case 3:
-		toggle_show_class ();
-		break;
-	case 4:
 		if (current && (current->screen == s))
 			toggle_isfloat (current);
 		break;
-	case 5:
+	case 4:
 		if (current && (current->screen == s))
 			toggle_istool (current);
 		break;
-	case 6:
+	case 5:
 		if (current && (current->screen == s))
 			toggle_issticky (current);
 		break;
-	case 7:
-		if (current && (current->screen == s))
-			toggle_isnotile (current);
-		break;
 	}
 }
 
@@ -166,12 +154,6 @@ void next_hidden (void)
 	update_tbar ();
 }
 
-void toggle_show_class (void)
-{
-	show_class = !show_class;
-	update_tbar ();
-}
-
 void update_cmd_output (void)
 {
 	XTextProperty pr;
@@ -196,49 +178,25 @@ void update_cmd_output (void)
 
 void draw_tbar (ScreenInfo *s)
 {
-	int tlen;
+	int tlen, max_tlen;
 	char sbar[256], tmp[256];
 
 	if (!s)
 		return;
 
 	XClearWindow(dpy, s->barwin);
-
-	if (bar_hidden <= MENU_BASE)
-	{
-		XDrawString (dpy, s->barwin, s->gc, BAR_HEIGHT, BAR_TEXT_Y, menu[-bar_hidden + MENU_BASE], mlen[-bar_hidden + MENU_BASE]);
-	}
-	else if ((bar_hidden >= 0) && (bar_hidden < numhidden))
-	{
-		Client *c = hiddenc[bar_hidden];
-
-		if (c->screen == s)
-			sprintf (tmp, "Hidden [%d/%d]  %s", bar_hidden + 1, numhidden, c->iconname ? c->iconname : c->label);
-		else
-			sprintf (tmp, "Other Screen [%d/%d]  %s", bar_hidden + 1, numhidden, c->iconname ? c->iconname : c->label);
-
-		tlen = strlen (tmp);
-
-		if (tlen > 0)
-		{
-			XDrawString (dpy, s->barwin, s->gc, BAR_HEIGHT, BAR_TEXT_Y, tmp, tlen);
-		}
-	}
-	else if (current && current->label && (current->screen == s))
-	{
-		tlen = strlen (current->label);
-
-		if (tlen > 0)
-		{
-			XDrawString (dpy, s->barwin, s->gc, BAR_HEIGHT, BAR_TEXT_Y, current->label, tlen);
-		}
-	}
+#ifdef THREE_D
+	XDrawLine(dpy, s->barwin, s->botwhitegc, 0, BAR_HEIGHT, BAR_WIDTH(s), BAR_HEIGHT);
+	XDrawLine(dpy, s->barwin, s->botwhitegc, BAR_WIDTH(s), BAR_HEIGHT, BAR_WIDTH(s), 0);
+	XDrawLine(dpy, s->barwin, s->topwhitegc, 0, 0, BAR_WIDTH(s), 0);
+	XDrawLine(dpy, s->barwin, s->topwhitegc, 0, 0, 0, BAR_HEIGHT);
+#endif
 
 	sbar[0] = '\0';
 
-	if (show_class && current && (current->screen == s) && !((bar_hidden >= 0) && (bar_hidden < numhidden)))
+	if (current && (current->screen == s) && !((bar_hidden >= 0) && (bar_hidden < numhidden)))
 	{
-		strcat (sbar, "(");
+		strcpy (sbar, "(");
 
 		if (current->class)
 			strcat (sbar, current->class);
@@ -295,6 +253,70 @@ void draw_tbar (ScreenInfo *s)
 	{
 		int plen = XTextWidth (font, sbar, tlen);
 		XDrawString (dpy, s->barwin, s->gc, BAR_WIDTH(s) - plen - BAR_HEIGHT, BAR_TEXT_Y, sbar, tlen);
+
+		/* space left on left */
+		max_tlen = BAR_WIDTH(s) - plen - (3 * BAR_HEIGHT);
+		if (max_tlen < 1)
+			max_tlen = 1;
+	}
+	
+	/* print current window's label */
+	if (bar_hidden <= MENU_BASE)
+	{
+		XDrawString (dpy, s->barwin, s->gc, BAR_HEIGHT, BAR_TEXT_Y, menu[-bar_hidden + MENU_BASE], mlen[-bar_hidden + MENU_BASE]);
+	}
+	else if ((bar_hidden >= 0) && (bar_hidden < numhidden))
+	{
+		Client *c = hiddenc[bar_hidden];
+		unsigned short int changed = 0;
+
+		if (c->screen == s)
+			sprintf (tmp, "Hidden [%d/%d]  %s", bar_hidden + 1, numhidden, c->iconname ? c->iconname : c->label);
+		else
+			sprintf (tmp, "Other Screen [%d/%d]  %s", bar_hidden + 1, numhidden, c->iconname ? c->iconname : c->label);
+
+		tlen = strlen (tmp);
+
+		while (tlen > 0 && XTextWidth (font, tmp, tlen) > max_tlen)
+		{
+			tlen--;
+			changed = 1;
+		}
+
+		if (changed && tlen > 10)
+		{
+			tmp[tlen - 3] = '\0';
+			strcat (tmp, "...");
+		}
+		
+		if (tlen > 0)
+		{
+			XDrawString (dpy, s->barwin, s->gc, BAR_HEIGHT, BAR_TEXT_Y, tmp, tlen);
+		}
+	}
+	else if (current && current->label && (current->screen == s))
+	{
+		unsigned short int changed = 0;
+		
+		strcpy (tmp, current->label);
+		tlen = strlen (tmp);
+
+		while (tlen > 0 && XTextWidth (font, tmp, tlen) > max_tlen)
+		{
+			tlen--;
+			changed = 1;
+		}
+		
+		if (changed && tlen > 10)
+		{
+			tmp[tlen - 3] = '\0';
+			strcat (tmp, "...");
+		}
+
+		if (tlen > 0)
+		{
+			XDrawString (dpy, s->barwin, s->gc, BAR_HEIGHT, BAR_TEXT_Y, tmp, tlen);
+		}
 	}
 }
 
