@@ -1,19 +1,29 @@
 /* Copyright (c) 1994-1996 David Hogan, see README for licence details */
 /* Many changes by Lars Bernhardsson. */
+/* Less changes by Florian Forster <octopus@verplant.org> */
 
-#define VERSION		"larswm 7.0.14 by Lars Bernhardsson"
+#define VERSION		"larswm 7.2.8 [26-OCT-2002] by Lars Bernhardsson <lab@fnurt.net>\n" \
+			"Tiling patch by Florian Forster <octopus@verplant.org>"
 
 #define BORDER		2
-#define TILE_PAD	1
+#define TILE_PAD	2
 
 #define BAR_X(s)	0
 #define BAR_Y(s)	(DisplayHeight (dpy, (s)->num) - BAR_HEIGHT)
 #define BAR_WIDTH(s)	(DisplayWidth (dpy, (s)->num))
+
+#ifdef THREE_D
+#define BAR_HEIGHT	(4 + font->ascent + font->descent)
+#define BAR_TEXT_Y	(2 + font->ascent)
+#else
 #define BAR_HEIGHT	(font->ascent + font->descent)
 #define BAR_TEXT_Y	(font->ascent)
+#endif
 
 #define DEFSHELL	"/bin/sh"
 
+#define DEFRC		"/etc/X11/larswmrc"
+
 #define MAXSCREENS	4
 #define MAXDESKTOPS	16
 
@@ -34,6 +44,11 @@
 #define DIM_VERT	1
 #define DIM_HORIZ	2
 
+/* to keep track of if a window is zoomed max */
+/* height/width/both or select zoomed */
+#define ZOOM_UNZOOMED 0
+#define ZOOM_NORMAL 1
+#define ZOOM_SELECT 2
 
 typedef struct Client Client;
 typedef struct ScreenInfo ScreenInfo;
@@ -101,8 +116,20 @@ struct ScreenInfo {
 	Window		barwin;
 	Colormap	def_cmap;
 	GC		gc;
+#ifdef THREE_D
+	GC		topwhitegc;
+	GC		botwhitegc;
+	GC		topblackgc;
+	GC		botblackgc;
+#endif
 	unsigned long	black;
 	unsigned long	white;
+#ifdef THREE_D
+	unsigned long	topwhite;
+	unsigned long	botwhite;
+	unsigned long	topblack;
+	unsigned long	botblack;
+#endif
 	int		min_cmaps;
 	Cursor		place;
 	Cursor		sweep;
@@ -194,6 +221,12 @@ struct Prefs {
 	KeySym		move_southeast_key;
 	unsigned long	move_southeast_mod;
 
+	KeySym		move_select_key;
+	unsigned long	move_select_mod;
+
+	KeySym		move_sd_key;
+	unsigned long	move_sd_mod;
+
 	KeySym		toggle_inc_key;
 	unsigned long	toggle_inc_mod;
 
@@ -265,7 +298,6 @@ extern char 		*shell;
 extern Atom		exit_larswm;
 extern Atom		restart_larswm;
 extern Atom		bartext_larswm;
-extern Atom		selection_larswm;
 
 extern Atom 		wm_state;
 extern Atom		wm_change_state;
