@@ -104,7 +104,6 @@ void mainloop(int shape_event)
 			reparent(&ev.xreparent);
 			break;
 		case SelectionNotify:
-			selection (&ev.xselection);
 			break;
 		case EnterNotify:
 			enter(&ev.xcrossing);
@@ -122,32 +121,6 @@ void mainloop(int shape_event)
 	}
 }
 
-void selection (XSelectionEvent *e)
-{
-	ScreenInfo *s;
-
-	if (!(s = getbarscreen (e->requestor)))
-		return;
-
-	if (!selapp)
-		return;
-
-	if (e->property != None)
-	{
-		XTextProperty pr;
-
-		if (XGetTextProperty (dpy, e->requestor, &pr, selection_larswm))
-		{
-			strncpy (seltext, (char *) pr.value, sizeof (seltext));
-			XFree (pr.value);
-		}
-	}
-
-	spawn (s, selapp);
-
-	selapp = 0;
-}
-
 void expose(XExposeEvent *e)
 {
 	Client *c;
@@ -271,7 +244,8 @@ void mapreq(XMapRequestEvent *e)
 		top (c);
 		wmsetstate(c, NormalState);
 
-		if ((mouse_on_screen() == c->screen) || (current && (current->screen == c->screen)))
+		if ((mouse_on_screen() == c->screen) 
+			|| (current && (current->screen == c->screen)))
 		{
 			active (c);
 		}
