@@ -35,7 +35,7 @@ int main(int argc, char **argv)
 		}
 		else
 		{
-			fprintf(stderr, "usage: smallclock [-display display]\n");
+			fprintf(stderr, "usage: %s [-display display]\n", argv[0]);
 			exit(1);
 		}
 	}
