@@ -27,7 +27,6 @@ int 		num_screens;
 Atom		exit_larswm;
 Atom		restart_larswm;
 Atom		bartext_larswm;
-Atom		selection_larswm;
 
 Atom		wm_state;
 Atom		wm_change_state;
@@ -109,7 +108,6 @@ int main(int argc, char **argv)
 	exit_larswm = XInternAtom(dpy, "LARSWM_EXIT", False);
 	restart_larswm = XInternAtom(dpy, "LARSWM_RESTART", False);
 	bartext_larswm = XInternAtom(dpy, "LARSWM_BARTEXT", False);
-	selection_larswm = XInternAtom(dpy, "LARSWM_SELECTION", False);
 
 	wm_state = XInternAtom(dpy, "WM_STATE", False);
 	wm_change_state = XInternAtom(dpy, "WM_CHANGE_STATE", False);
@@ -236,6 +234,92 @@ void initscreen(ScreenInfo *s, int i)
 		s->white = WhitePixel(dpy, i);
 	}
 
+#ifdef THREE_D
+#define MIN(x,y) (unsigned short) (x < y) ? x : y
+	{
+		XColor topcolor;
+		XColor botcolor;
+		XColor get_c;
+
+		get_c.pixel = s->white;
+
+		if ((get_c.pixel == WhitePixel (dpy, s->num)) ||
+		    (get_c.pixel == BlackPixel (dpy, s->num)))
+		{
+			topcolor.red = MIN (65535, (13 * 35000) / 10);
+			topcolor.green = MIN (65535, (13 * 35000) / 10);
+			topcolor.blue = MIN (65535, (13 * 35000) / 10);
+			botcolor.red = (7 * 35000) / 10;
+			botcolor.green = (7 * 35000) / 10;
+			botcolor.blue = (7 * 35000) / 10;
+		}
+		else
+		{
+			XQueryColor (dpy, s->def_cmap, &get_c);
+			topcolor.red = MIN (65535, (13 * get_c.red) / 10);
+			topcolor.green = MIN (65535, (13 * get_c.green) / 10);
+			topcolor.blue = MIN (65535, (13 * get_c.blue) / 10);
+			botcolor.red = (7 * get_c.red) / 10;
+			botcolor.green = (7 * get_c.green) / 10;
+			botcolor.blue = (7 * get_c.blue) / 10;
+		}
+
+		XAllocColor (dpy, s->def_cmap, &topcolor);
+		XAllocColor (dpy, s->def_cmap, &botcolor);
+		s->topwhite = topcolor.pixel;
+		s->botwhite = botcolor.pixel;
+
+		gv.foreground = s->topwhite;
+		gv.line_width = 2 * BORDER;
+		mask = GCForeground | GCLineWidth;
+		s->topwhitegc = XCreateGC(dpy, s->root, mask, &gv);
+
+		gv.foreground = s->botwhite;
+		gv.line_width = 2 * BORDER;
+		mask = GCForeground | GCLineWidth;
+		s->botwhitegc = XCreateGC(dpy, s->root, mask, &gv);
+
+		get_c.pixel = s->black;
+
+		if ((get_c.pixel == WhitePixel (dpy, s->num)) ||
+		    (get_c.pixel == BlackPixel (dpy, s->num)))
+		{
+			topcolor.red = MIN (65535, (13 * 50000) / 10);
+			topcolor.green = MIN (65535, (13 * 20000) / 10);
+			topcolor.blue = MIN (65535, (13 * 20000) / 10);
+			botcolor.red = (7 * 50000) / 10;
+			botcolor.green = (7 * 20000) / 10;
+			botcolor.blue = (7 * 20000) / 10;
+		}
+		else
+		{
+			XQueryColor (dpy, s->def_cmap, &get_c);
+			topcolor.red = MIN (65535, (13 * get_c.red) / 10);
+			topcolor.green = MIN (65535, (13 * get_c.green) / 10);
+			topcolor.blue = MIN (65535, (13 * get_c.blue) / 10);
+			botcolor.red = (7 * get_c.red) / 10;
+			botcolor.green = (7 * get_c.green) / 10;
+			botcolor.blue = (7 * get_c.blue) / 10;
+		}
+
+		XAllocColor (dpy, s->def_cmap, &topcolor);
+		XAllocColor (dpy, s->def_cmap, &botcolor);
+		s->topblack = topcolor.pixel;
+		s->botblack = botcolor.pixel;
+
+		gv.foreground = s->topblack;
+		gv.line_width = 2 * BORDER;
+		mask = GCForeground | GCLineWidth;
+		s->topblackgc = XCreateGC(dpy, s->root, mask, &gv);
+
+		gv.foreground = s->botblack;
+		gv.line_width = 2 * BORDER;
+		mask = GCForeground | GCLineWidth;
+		s->botblackgc = XCreateGC(dpy, s->root, mask, &gv);
+	}
+#undef MIN
+#endif
+
 	gv.foreground = s->black^s->white;
 	gv.background = s->white;
 	gv.function = GXxor;
