@@ -258,58 +258,64 @@ void gravitate(Client *c, int invert)
 	int gravity, dx, dy, delta;
 
 	gravity = NorthWestGravity;
+
 	if (c->size.flags & PWinGravity)
 		gravity = c->size.win_gravity;
 
 	delta = c->border-BORDER;
 
-	switch (gravity) {
+	switch (gravity)
+       	{
 	case NorthWestGravity:
-		dx = 0;
-		dy = 0;
+		dx = delta + 1;
+		dy = delta + 1;
 		break;
 	case NorthGravity:
-		dx = delta;
-		dy = 0;
+		dx = delta + 1;
+		dy = delta + 1;
 		break;
 	case NorthEastGravity:
-		dx = 2*delta;
-		dy = 0;
+		dx = (2 * delta);
+		dy = delta + 1;
 		break;
 	case WestGravity:
-		dx = 0;
-		dy = delta;
+		dx = delta + 1;
+		dy = delta + 1;
 		break;
 	case CenterGravity:
 	case StaticGravity:
-		dx = delta;
-		dy = delta;
+		dx = delta + 1;
+		dy = delta + 1;
 		break;
 	case EastGravity:
-		dx = 2*delta;
-		dy = delta;
+		dx = (2 * delta);
+		dy = delta + 1;
 		break;
 	case SouthWestGravity:
-		dx = 0;
-		dy = 2*delta - (BAR_HEIGHT);
+		dx = delta + 1;
+		dy = (2 * delta) - BAR_HEIGHT;
 		break;
 	case SouthGravity:
-		dx = delta;
-		dy = 2*delta - (BAR_HEIGHT);
+		dx = delta + 1;
+		dy = (2 * delta) - BAR_HEIGHT;
 		break;
 	case SouthEastGravity:
-		dx = 2*delta;
-		dy = 2*delta - (BAR_HEIGHT);
+		dx = (2 * delta);
+		dy = (2 * delta) - BAR_HEIGHT;
 		break;
 	default:
 		return;
 	}
+
 	dx += BORDER;
 	dy += BORDER;
-	if (invert) {
+
+	if (invert)
+       	{
 		dx = -dx;
 		dy = -dy;
 	}
+
 	c->x += dx;
 	c->y += dy;
 }
