@@ -110,6 +110,12 @@ void set_defaults (void)
 	prefs.move_southeast_key = XK_KP_Next;
 	prefs.move_southeast_mod = DEFAULT_MOD;
 
+	prefs.move_select_key = XK_space;
+	prefs.move_select_mod = DEFAULT_MOD;
+
+	prefs.move_sd_key = XK_space;
+	prefs.move_sd_mod = MOVE_MOD;
+
 	prefs.toggle_inc_key = XK_KP_Insert;
 	prefs.toggle_inc_mod = MOVE_MOD;
 
@@ -389,6 +395,10 @@ void dump_prefs (void)
 	printf ("! larswm.next_window_mod: %s\n", show_mod (prefs.next_window_mod));
 	printf ("!\n");
 
+	printf ("! larswm.raise_notile_key: %s\n", XKeysymToString (prefs.raise_notile_key));
+	printf ("! larswm.raise_notile_mod: %s\n", show_mod (prefs.raise_notile_mod));
+	printf ("!\n");
+
 	printf ("! larswm.move_northwest_key: %s\n", XKeysymToString (prefs.move_northwest_key));
 	printf ("! larswm.move_northwest_mod: %s\n", show_mod (prefs.move_northwest_mod));
 	printf ("!\n");
@@ -434,6 +444,13 @@ void dump_prefs (void)
 	printf ("! larswm.move_right_mod: %s\n", show_mod (prefs.move_right_mod));
 	printf ("!\n");
 
+	printf ("! larswm.move_select_key: %s\n", XKeysymToString (prefs.move_select_key));
+	printf ("! larswm.move_select_mod: %s\n", show_mod (prefs.move_select_mod));
+	printf ("!\n");
+	printf ("! larswm.move_sd_key: %s\n", XKeysymToString (prefs.move_sd_key));
+	printf ("! larswm.move_sd_mod: %s\n", show_mod (prefs.move_sd_mod));
+	printf ("!\n");
+
 	printf ("! larswm.grow_vert_key: %s\n", XKeysymToString (prefs.grow_vert_key));
 	printf ("! larswm.grow_vert_mod: %s\n", show_mod (prefs.grow_vert_mod));
 	printf ("!\n");
@@ -571,7 +588,8 @@ void load_prefs (char *filename)
 	set_defaults ();
 
 	if ((db = XrmGetFileDatabase (filename)) == NULL)
-		return;
+		if ((db = XrmGetFileDatabase (DEFRC)) == NULL)
+			return;
 
 	if (XrmGetResource (db, "larswm.desktops", "Larswm.Desktops", &vt, &v))
 		prefs.desktops = atoi (v.addr);
@@ -876,6 +894,19 @@ void load_prefs (char *filename)
 		prefs.move_right_mod = get_mod (v.addr);
 
 
+	if (XrmGetResource (db, "larswm.move_select_key", "Larswm.Move_select_key", &vt, &v))
+		prefs.move_select_key = XStringToKeysym (v.addr);
+
+	if (XrmGetResource (db, "larswm.move_select_mod", "Larswm.Move_select_mod", &vt, &v))
+		prefs.move_select_mod = get_mod (v.addr);
+
+	if (XrmGetResource (db, "larswm.move_sd_key", "Larswm.Move_sd_key", &vt, &v))
+		prefs.move_sd_key = XStringToKeysym (v.addr);
+
+	if (XrmGetResource (db, "larswm.move_sd_mod", "Larswm.Move_sd_mod", &vt, &v))
+		prefs.move_sd_mod = get_mod (v.addr);
+
+
 	if (XrmGetResource (db, "larswm.grow_vert_key", "Larswm.Grow_vert_key", &vt, &v))
 		prefs.grow_vert_key = XStringToKeysym (v.addr);
 
