@@ -228,14 +228,6 @@ void toggle_isfloat (Client *c)
 	update_tbar ();
 }
 
-void toggle_isnotile (Client *c)
-{
-	if (c)
-		c->isnotile = !c->isnotile;
-
-	update_tbar ();
-}
-
 void toggle_istool (Client *c)
 {
 	if (c)
@@ -448,79 +440,110 @@ void raise_trans(ScreenInfo *s)
 	}
 }
 
-void tile_all(ScreenInfo *s)
+void tile_all (ScreenInfo *s)
 {
 	Client *c;
-	int screen_height;
-	int adjust_height;
-	int num_clients, cpt[2], wh[2];
-	int cur_track, cur_pos;
+	
+	unsigned int screen_height_left, screen_height_right;
+	unsigned int track_width_left, track_width_right;
 
+	unsigned short clients_left, clients_right;
+	unsigned short current_client = 0;
+
+	unsigned short on_right = 0;
+	
 	if (!s)
 		abort ();
 
-	calc_track_sizes(s);
+	
+	calc_track_sizes(s);	
 	find_tools (s);
+        
+	track_width_left  = track_width[s->num][0];
+	track_width_right = track_width[s->num][1];
+	
+	screen_height_left  =
+		(res_track & 1 ? s->res_height : s->tile_height);
+	screen_height_right =
+		(res_track & 2 ? s->res_height : s->tile_height);
+	
+	clients_right = count_clients(s);
 
-	screen_height = s->tile_height;
-	adjust_height = s->res_height;
-
-	num_clients = count_clients(s);
-
-	if (num_clients == 0)
+	if (clients_right == 0)
 		return;
 
-	cpt[0] = num_clients;
-	cpt[1] = 0;
-
-	if (cpt[0] > 1)
-	{
-		cpt[0] = 1;
-		cpt[1] = num_clients - 1;
-	}
-
-	if (cpt[0] < 1)
-	{
-		cpt[0]++;
-		cpt[1]--;
-	}
-
-	wh[0] = (res_track & 1 ? adjust_height : screen_height) / (cpt[0] ? cpt[0] : 1);
-	wh[1] = (res_track & 2 ? adjust_height : screen_height) / (cpt[1] ? cpt[1] : 1);
-
-	cur_track = 0;
-	cur_pos = 0;
+	clients_left = 1;
+	--clients_right;
 
 	for(c = clients; c; c = c->next)
 	{
+		/*
+		 * WARNING
+		 * The variables "screen_height_left", "odx" and "ody"
+		 * have more than one purpose.
+		 */
 		if(DO_TILE(c, s))
 		{
-			int x, y, odx, ody, width, height;
+			unsigned int x, y, width, height;
+			unsigned int odx, ody;
 
-			c->isleft = 0;
-
-			x = track_x[s->num][cur_track];
-			y = cur_pos * wh[cur_track];
-
-			width = track_width[s->num][cur_track] - (2 * BORDER) - TILE_PAD;
-			height = wh[cur_track] - (2 * BORDER) - TILE_PAD;
-
-			if (cur_track == 1)
+			if (on_right)
 			{
-				width += TILE_PAD;
+				x = track_width_left;
+				y = screen_height_right
+					- screen_height_left;
+				height = screen_height_right
+					/ clients_right;
+				width = track_width_right;
+
+				if (++current_client < clients_right)
+				{
+					screen_height_left -= height;
+					height -= TILE_PAD;
+				}
+				else
+					height = screen_height_left;
+				
+			}
+			else
+			{
+				x = y = 0;
+				height = screen_height_left;
+				width = track_width_left - TILE_PAD;
+
+				/*
+				 * Here the purpose of
+				 * screen_height_left changes
+				 */
+				screen_height_left = screen_height_right;
 			}
 
-			if ((cur_pos + 1) == cpt[cur_track])
-			{
-				height += TILE_PAD;
-			}
+			height -= 2 * BORDER;
+			width  -= 2 * BORDER;
+			
+			c->isleft = on_right ? 0 : 1;
 
+			odx = width;
+			ody = height;
+			
+			/*
+			 * resize in given increments if the program
+			 * wishes this..
+			 */
 			if (c->size.flags & PResizeInc)
 			{
-				width = c->min_dx + (width - c->min_dx) / c->size.width_inc * c->size.width_inc;
-				height = c->min_dy + (height - c->min_dy) / c->size.height_inc * c->size.height_inc;
+				width = c->min_dx +
+					(((signed int) (width -
+					c->min_dx) / c->size.width_inc) *
+					c->size.width_inc);
+				
+				height = c->min_dy +
+					(((signed int) (height -
+					c->min_dy) / c->size.height_inc) *
+					c->size.height_inc);
 			}
 
+			/* don't exceed this size */
 			if (c->size.flags & PMaxSize)
 			{
 				if (width > c->size.max_width)
@@ -529,52 +552,63 @@ void tile_all(ScreenInfo *s)
 				if (height > c->size.max_height)
 					height = c->size.max_height;
 			}
-
+			
+			/*
+			 * adjust track width if left window doesn't use
+			 * all of it or height left if a right window
+			 * doesn't use it all..
+			 */
+			if (on_right)
+			{
+				if (ody != height)
+					screen_height_left +=
+						ody - height;
+			}
+			else if (odx != width)
+			{
+				track_width_right +=
+					odx - width;
+				track_width_left -=
+					odx - width;
+			}
+		
+			/*
+			 * The second meaning begins
+			 */
 			odx = c->dx;
 			ody = c->dy;
 
 			c->x = x;
 			c->y = y;
 
-			if (s->tile_resize[s->desktop] || ((cur_track == 0) && (cur_pos == 0)))
+			/*
+			 * if resize is true OR we're at the upper left corner
+			 * set size to maximum
+			 */
+			if (s->tile_resize[s->desktop] || !on_right)
 			{
 				c->dx = width;
 				c->dy = height;
-
 			}
 
-			XMoveResizeWindow (dpy, c->parent,
-				           c->x, c->y,
-					   c->dx + (2 * BORDER), c->dy + (2 * BORDER));
+			XMoveResizeWindow (dpy, c->parent, c->x, c->y,
+					   c->dx + (2 * BORDER),
+					   c->dy + (2 * BORDER));
+			XResizeWindow (dpy, c->window, c->dx, c->dy);
+			sendconfig (c);
 
-			if ((c->dx == odx) && (c->dy == ody))
+			/* give focus to window if appropriate */
+			if (c->isleft
+				&& (mouse_on_screen () == s)
+				&& !s->notile_raised[s->desktop])
 			{
-				sendconfig (c);
-			}
-			else
-			{
-				XMoveResizeWindow (dpy, c->window,
-					           BORDER, BORDER, c->dx, c->dy);
-			}
-
-			if ((cur_track == 0) && (cur_pos == 0))
-			{
-				c->isleft = 1;
-			}
-
-			if (c->isleft && (mouse_on_screen () == s) && !s->notile_raised[s->desktop])
-			{
-				if (!current || !s->skip_focus[s->desktop] || !s->tile_resize[s->desktop])
+				if (!current 
+					|| !s->skip_focus[s->desktop] 
+					|| !s->tile_resize[s->desktop])
 					active (c);
 			}
-
-			cur_pos++;
-
-			if (cur_pos >= cpt[cur_track])
-			{
-				cur_track++;
-				cur_pos = 0;
-			}
+				
+			on_right = 1;
 		}
 	}
 
@@ -759,6 +793,7 @@ void prev_window (ScreenInfo *s)
 					XMapRaised (dpy, c->parent);
 					tile_all (s);
 				}
+
 				return;
 			}
 		}
@@ -842,7 +877,7 @@ void next_window (ScreenInfo *s)
 					XMapRaised (dpy, c->parent);
 					tile_all (s);
 				}
-	
+
 				return;
 			}
 		}
@@ -1230,7 +1265,11 @@ void zoom (Client *c, int dimension)
 				tile_all (c->screen);
 			}
 		}
-		else if (c->iszoom)
+		else if (c->iszoom == ZOOM_SELECT)
+		{
+			move_select (c, 0);
+		}
+		else if (c->iszoom == ZOOM_NORMAL)
 		{
 			c->x = c->zx;
 			c->y = c->zy;
@@ -1238,17 +1277,10 @@ void zoom (Client *c, int dimension)
 			c->dy = c->zdy;
 
 			XMoveResizeWindow (dpy, c->parent, c->x, c->y, c->dx + (2 * BORDER), c->dy + (2 * BORDER));
+			XResizeWindow (dpy, c->window, c->dx, c->dy);
+			sendconfig (c);
 
-			if ((c->dx == odx) && (c->dy == ody))
-			{
-				sendconfig (c);
-			}
-			else
-			{
-				XMoveResizeWindow (dpy, c->window, BORDER, BORDER, c->dx, c->dy);
-			}
-
-			c->iszoom = 0;
+			c->iszoom = ZOOM_UNZOOMED;
 		}
 		else
 		{
@@ -1288,13 +1320,10 @@ void zoom (Client *c, int dimension)
 			}
 
 			XMoveResizeWindow (dpy, c->parent, c->x, c->y, c->dx + (2 * BORDER), c->dy + (2 * BORDER));
+			XResizeWindow (dpy, c->window, c->dx, c->dy);
+			sendconfig (c);
 
-			if ((c->dx == odx) && (c->dy == ody))
-				sendconfig (c);
-			else
-				XMoveResizeWindow (dpy, c->window, BORDER, BORDER, c->dx, c->dy);
-
-			c->iszoom = 1;
+			c->iszoom = ZOOM_NORMAL;
 		}
 	}
 }
@@ -1310,7 +1339,7 @@ void grow (Client *c, int dimension, int m)
 
 	if (!c->isnotile)
 	{
-		if (dimension == DIM_HORIZ)
+		if ((dimension == DIM_HORIZ) || (dimension == (DIM_HORIZ | DIM_VERT)))
 		{
 			if (m > 0)
 				grow_left (c->screen);
@@ -1434,5 +1463,160 @@ void grow (Client *c, int dimension, int m)
 	}
 
 	XMoveResizeWindow (dpy, c->parent, c->x, c->y, c->dx + (2 * BORDER), c->dy + (2 * BORDER));
-	XMoveResizeWindow (dpy, c->window, BORDER, BORDER, c->dx, c->dy);
+	XResizeWindow (dpy, c->window, c->dx, c->dy);
+	sendconfig (c);
+}
+
+void move_select (Client *c, int untiled)
+{
+	int h, w, dh, dw, x, y;
+	int odx, ody;
+
+	if (!c || !c->isnotile)
+		return;
+
+	odx = c->dx;
+	ody = c->dy;
+
+	if (c->iszoom == ZOOM_NORMAL)
+	{
+		zoom (c, DIM_HORIZ | DIM_VERT);
+
+		return;
+	}
+	else if (c->iszoom == ZOOM_SELECT)
+	{
+		c->x = c->zx;
+		c->y = c->zy;
+		c->dx = c->zdx;
+		c->dy = c->zdy;
+
+		XMoveResizeWindow (dpy, c->parent, c->x, c->y, c->dx + (2 * BORDER), c->dy + (2 * BORDER));
+		XResizeWindow (dpy, c->window, c->dx, c->dy);
+		sendconfig (c);
+
+		XMapRaised(dpy, c->parent);
+		top (c);
+		active (c);
+
+		if (!c->screen->notile_raised[c->screen->desktop])
+			raise_notile (c->screen);
+
+		c->iszoom = ZOOM_UNZOOMED;
+
+		return;
+	}
+
+	x = c->x;
+	y = c->y;
+
+	w = odx;
+	h = ody;
+
+	dh = c->screen->tile_height - (2 * BORDER);
+	dw = DisplayWidth (dpy, c->screen->num) - (2 * BORDER);
+
+	if (untiled) /* window that just stopped being tiled, leave it centered and smaller */
+	{
+		h = dh / 2;
+		w = dw / 2;
+	}
+	else
+	{
+		h = dh;
+		w = (17 * h) / 22; /* US letter paper ratio */
+	}
+
+	if (w > dw) /* for screens with non-standard ratios */
+		w = dw;
+
+	if (c->size.flags & PResizeInc)
+	{
+		w = c->min_dx + (w - c->min_dx) / c->size.width_inc * c->size.width_inc;
+		h = c->min_dy + (h - c->min_dy) / c->size.height_inc * c->size.height_inc;
+	}
+
+	if (c->size.flags & PMinSize)
+	{
+		if (w < c->size.min_width)
+			w = c->size.min_width;
+
+		if (h < c->size.min_height)
+			h = c->size.min_height;
+	}
+
+	if (c->size.flags & PMaxSize)
+	{
+		if (w > c->size.max_width)
+			w = c->size.max_width;
+
+		if (h > c->size.max_height)
+			h = c->size.max_height;
+	}
+
+	x = (DisplayWidth (dpy, c->screen->num) / 2) - (w / 2) - BORDER;
+	y = (c->screen->tile_height / 2) - (h / 2) - BORDER;
+
+	if (c->x < 0)
+		c->x = 0;
+
+	if (c->y < 0)
+		c->y = 0;
+
+	c->zx = c->x;
+	c->zy = c->y;
+	c->zdx = c->dx;
+	c->zdy = c->dy;
+
+	if (w != odx)
+	{
+		c->x = x;
+		c->dx = w;
+	}
+
+	if (h != ody)
+	{
+		c->y = y;
+		c->dy = h;
+	}
+
+	XMoveResizeWindow (dpy, c->parent, c->x, c->y, c->dx + (2 * BORDER), c->dy + (2 * BORDER));
+	XResizeWindow (dpy, c->window, c->dx, c->dy);
+	sendconfig (c);
+
+	XMapRaised(dpy, c->parent);
+	top (c);
+	active (c);
+
+	if (!c->screen->notile_raised[c->screen->desktop])
+		raise_notile (c->screen);
+
+	if (untiled) /* if just stopped being tiled, do not count this as zoomed */
+		c->iszoom = ZOOM_UNZOOMED;
+	else
+		c->iszoom = ZOOM_SELECT;
+}
+
+void move_sd (Client *c)
+{
+	if (!c)
+		return;
+
+	c->iszoom = ZOOM_UNZOOMED;
+
+	if (c->isnotile)
+	{
+		c->isnotile = 0;
+		raise_tile (c->screen, 0);
+		top (c);
+		active (c);
+		tile_all (c->screen);
+	}
+	else
+	{
+		c->isnotile = 1;
+		tile_all (c->screen);
+		raise_notile (c->screen);
+		move_select (c, 1);
+	}
 }
